==> moengagesdk-2.0.16-sources.jar: com/moengage/core/InAppNetworkCallsTask.java <==
package com.moengage.core;

import android.content.Context;
import android.text.TextUtils;
import com.moengage.ActionMapperConstants;
import com.moengage.core.executor.SDKTask;
import com.moengage.core.executor.TaskResult;
import com.moengage.inapp.InAppController;
import java.util.HashMap;
import org.json.JSONObject;

/**
 * API Calls related to in-apps
 *
 * @author Umang Chamaria
 */
public class InAppNetworkCallsTask extends SDKTask {

  HashMap<String, String> paramsMap;
  String API;
  String requestBody;
  InAppController.NETWORK_CALL_TYPE networkCallType;
  InAppController.InAppHandler inAppHandler;

  public InAppNetworkCallsTask(Context context, String API, HashMap<String, String> paramsMap,
      String requestBody, InAppController.NETWORK_CALL_TYPE networkCallType) {
    super(context);
    this.API = API;
    this.paramsMap = paramsMap;
    this.requestBody = requestBody;
    this.networkCallType = networkCallType;
    inAppHandler = InAppController.getInstance().getInAppHandler();
  }

  @Override public TaskResult execute() {
    Logger.v("InAppNetworkCallsTask : started execution, Task Type : " + networkCallType);
    String response = null;
    JSONObject jsonResponse;
    if (inAppHandler != null) {
      try {
        if (!ConfigurationProvider.getInstance(mContext).isInAppEnabled()
            || !ConfigurationProvider.getInstance(mContext).isAppEnabled()) return null;
        switch (networkCallType) {
          case SYNC_IN_APPS:
            Logger.v("InAppNetworkCallsTask: executing sync in-apps");
            mTaskResult.setPayload(InAppController.NETWORK_CALL_TYPE.SYNC_IN_APPS);
            response = APIManager.fetchInAppCampaigns(mContext, API, paramsMap, requestBody);
            if (!TextUtils.isEmpty(response)) {
              jsonResponse = new JSONObject(response);
              inAppHandler.parseAndSaveInApps(jsonResponse, mContext);
              mTaskResult.setIsSuccess(true);
            } else {
              Logger.e("MoEParser:parseAndSaveCampaignInfo not a valid response");
            }
            break;
          case AUTO_TRIGGER_EVENT:
            Logger.v("InAppNetworkCallsTask: executing auto-trigger in-apps");
            response = APIManager.logASmartEvent(mContext, API, paramsMap, requestBody);
            if (!TextUtils.isEmpty(response)) {
              jsonResponse = new JSONObject(response);
              inAppHandler.tryShowAutoTriggerInApp(mContext, jsonResponse);
            }
            break;
          case SINGLE_FETCH:
            Logger.v("InAppNetworkCallsTask: executing single fetch in-apps");
            response = APIManager.fetchSingleInApp(mContext, API, paramsMap);
            if (!TextUtils.isEmpty(response)) {
              jsonResponse = new JSONObject(response);
              inAppHandler.showLinkedInApp(mContext, jsonResponse, paramsMap);
            } else {
              String errorString =
                  "Network Error Could not show test in-app.\n CampaignId : "
                      + paramsMap.get(ActionMapperConstants.KEY_CAMPAIGN_ID)
                      + ".\nPlease try again or "
                      + "contact MoEngage Support with the screenshot.";
              inAppHandler.showTestInAppErrorDialog(errorString);
            }
            break;
        }
      } catch (Exception e) {
        Logger.f("InAppNetworkCallsTask : execute JSONException", e);
      }
    }
    Logger.v("InAppNetworkCallsTask : completed execution");
    return mTaskResult;
  }

  @Override public String getTaskTag() {
    return TAG_INAPP_NETWORK_TASK;
  }

  @Override public boolean isSynchronous() {
    return false;
  }
}

==> moengagesdk-3.0.02-sources.jar: com/moengage/core/InAppNetworkCallsTask.java <==
package com.moengage.core;

import android.content.Context;
import android.text.TextUtils;
import com.moengage.ActionMapperConstants;
import com.moengage.core.executor.SDKTask;
import com.moengage.core.executor.TaskResult;
import com.moengage.inapp.InAppController;
import java.util.HashMap;
import org.json.JSONObject;

/**
 * API Calls related to in-apps
 *
 * @author Umang Chamaria
 */
public class InAppNetworkCallsTask extends SDKTask {

  private HashMap<String, String> paramsMap;
  String API;
  private String requestBody;
  private InAppController.NETWORK_CALL_TYPE networkCallType;
  private InAppController.InAppHandler inAppHandler;

  public InAppNetworkCallsTask(Context context, String API, HashMap<String, String> paramsMap,
      String requestBody, InAppController.NETWORK_CALL_TYPE networkCallType) {
    super(context);
    this.API = API;
    this.paramsMap = paramsMap;
    this.requestBody = requestBody;
    this.networkCallType = networkCallType;
    inAppHandler = InAppController.getInstance().getInAppHandler();
  }

  @Override public TaskResult execute() {
    Logger.v("InAppNetworkCallsTask : started execution, Task Type : " + networkCallType);
    String response = null;
    JSONObject jsonResponse;
    if (inAppHandler != null) {
      try {
        if (!ConfigurationProvider.getInstance(mContext).isInAppEnabled()
            || !ConfigurationProvider.getInstance(mContext).isAppEnabled()) return null;
        switch (networkCallType) {
          case SYNC_IN_APPS:
            Logger.v("InAppNetworkCallsTask: executing sync in-apps");
            mTaskResult.setPayload(InAppController.NETWORK_CALL_TYPE.SYNC_IN_APPS);
            response = APIManager.fetchInAppCampaigns(mContext, API, paramsMap, requestBody);
            if (!TextUtils.isEmpty(response)) {
              jsonResponse = new JSONObject(response);
              inAppHandler.parseAndSaveInApps(jsonResponse, mContext);
              mTaskResult.setIsSuccess(true);
            } else {
              Logger.e("MoEParser:parseAndSaveCampaignInfo not a valid response");
            }
            break;
          case AUTO_TRIGGER_EVENT:
            Logger.v("InAppNetworkCallsTask: executing auto-trigger in-apps");
            response = APIManager.logASmartEvent(mContext, API, paramsMap, requestBody);
            if (!TextUtils.isEmpty(response)) {
              jsonResponse = new JSONObject(response);
              inAppHandler.tryShowAutoTriggerInApp(mContext, jsonResponse);
            }
            break;
          case SINGLE_FETCH:
            Logger.v("InAppNetworkCallsTask: executing single fetch in-apps");
            response = APIManager.fetchSingleInApp(mContext, API, paramsMap);
            if (!TextUtils.isEmpty(response)) {
              jsonResponse = new JSONObject(response);
              inAppHandler.showLinkedInApp(mContext, jsonResponse, paramsMap);
            } else {
              String errorString =
                  "Network Error Could not show test in-app.\n CampaignId : "
                      + paramsMap.get(ActionMapperConstants.KEY_CAMPAIGN_ID)
                      + ".\nPlease try again or "
                      + "contact MoEngage Support with the screenshot.";
              inAppHandler.showTestInAppErrorDialog(errorString);
            }
            break;
        }
      } catch (Exception e) {
        Logger.f("InAppNetworkCallsTask : execute JSONException", e);
      }
    }
    Logger.v("InAppNetworkCallsTask : completed execution");
    return mTaskResult;
  }

  @Override public String getTaskTag() {
    return TAG_INAPP_NETWORK_TASK;
  }

  @Override public boolean isSynchronous() {
    return false;
  }
}
